@@ -20,8 +20,22 @@ class CommandType(Enum):
     GenerateLib = 15
     InvokeGlobalMethod = 16
     DestructReference = 17
-    Array = 18
+    ArrayReference = 18
     ArrayGetItem = 19
     ArrayGetSize = 20
     ArrayGetRank = 21
     ArraySetItem = 22
+    Array = 23
+    RetrieveArray = 24
+    SetInstanceField = 25
+    InvokeGenericStaticMethod = 26
+    InvokeGenericMethod = 27
+    GetEnumItem = 28
+    GetEnumName = 29
+    GetEnumValue = 30
+    AsRef = 31
+    AsOut = 32
+    GetRefValue = 33
+    EnableNamespace = 34
+    EnableType = 35
+    CreateNull = 36
