@@ -4,13 +4,9 @@ use strict;
 use lib 'lib';
 use FFI::Platypus;
 use Path::Tiny;
-use Exporter;
 use File::Spec;
 my $ffi;
 
-our @ISA = qw(Exporter);
-our @EXPORT = qw(send_command_ activate_);
-
 my $send_command_native;
 my $read_response_native;
 my $activate_native;
@@ -51,7 +47,7 @@ sub send_command {
     if ($response_array_len > 0) {
         my @response_array = (1 .. $response_array_len);
         $read_response_native->(\@response_array, $response_array_len);
-        return @response_array;
+        return \@response_array;
     }
     elsif ($response_array_len == 0) {
         my $error_message = "Response is empty";
